@@ -12,13 +12,15 @@
 #-*
 #Z* -------------------------------------------------------------------
 
+from __future__ import print_function
+
 if __name__=='pymol.querying':
 
     import time
-    import selector
+    from . import selector
     import pymol
-    import cmd
-    from cmd import _cmd,lock,unlock,Shortcut, \
+    cmd = __import__("sys").modules["pymol.cmd"]
+    from .cmd import _cmd,lock,unlock,Shortcut, \
           _feedback,fb_module,fb_mask,is_list, \
           DEFAULT_ERROR, DEFAULT_SUCCESS, _raising, is_ok, is_error
 
@@ -77,32 +79,15 @@ DESCRIPTION
             _self.unlock(r,_self)
         return r
 
-    def get_volume_is_updated(objName,_self=cmd):
-        print ' DEPRECATED: get_volume_is_updated'
-        return 1
- 
     def get_unused_name(prefix="tmp",alwaysnumber=1,_self=cmd):
-        r = DEFAULT_ERROR        
-        # should replace this with a C function
+        r = DEFAULT_ERROR
         try:
-            # remove non-safe chars
-            prefix = _self.get_legal_name(prefix)
-
-            _self.lock(_self)  
-            avoid_set = set(_self.get_names('all'))
-            if alwaysnumber or prefix in avoid_set:
-                counter = 1
-                while 1:
-                    r = prefix + "%02d"%counter
-                    if r not in avoid_set:
-                        break
-                    counter = counter + 1
-            else:
-                r=prefix
+            _self.lock(_self)
+            r = _cmd.get_unused_name(_self._COb, prefix, alwaysnumber)
         finally:
             _self.unlock(r,_self)
         return r
-    
+
     def get_modal_draw(_self=cmd,quiet=1):
         r = DEFAULT_ERROR
         try:
@@ -150,12 +135,22 @@ DESCRIPTION
             r = _cmd.get_object_ttt(_self._COb, str(object), -1, quiet)
         if not quiet:
             if r is None:
-                print 'TTT is None'
+                print('TTT is None')
             else:
                 for i in range(4):
                     if i == 3:
-                        print 'TTT ---------------------------+---------'
-                    print 'TTT %8.2f %8.2f %8.2f | %8.2f' % tuple(r[i * 4:i * 4 + 4])
+                        print('TTT ---------------------------+---------')
+                    print('TTT %8.2f %8.2f %8.2f | %8.2f' % tuple(r[i * 4:i * 4 + 4]))
+        return r
+
+    def get_object_settings(object, state=0, quiet=1, _self=cmd):
+        '''
+DESCRIPTION
+
+    "get_object_settings" is an unsupported command
+        '''
+        with _self.lockcm:
+            r = _cmd.get_object_settings(_self._COb, str(object), int(state) - 1)
         return r
 
     def get_object_list(selection="(all)", quiet=1, _self=cmd):
@@ -174,7 +169,7 @@ DESCRIPTION
             r = _cmd.get_object_list(_self._COb,str(selection))
             if not quiet:
                 if(is_list(r)):
-                    print " get_object_list: ",str(r)
+                    print(" get_object_list: ",str(r))
         finally:
             _self.unlock(r,_self)
         if _raising(r,_self): raise pymol.CmdException
@@ -205,11 +200,11 @@ PYMOL API
             if not quiet:
                 if(is_list(r)):
                     if(len(r)):
-                        print " get_symmetry: A     = %7.3f B    = %7.3f C     = %7.3f"%tuple(r[0:3])
-                        print " get_symmetry: Alpha = %7.3f Beta = %7.3f Gamma = %7.3f"%tuple(r[3:6])
-                        print " get_symmetry: SpaceGroup = %s"%r[6]
+                        print(" get_symmetry: A     = %7.3f B    = %7.3f C     = %7.3f"%tuple(r[0:3]))
+                        print(" get_symmetry: Alpha = %7.3f Beta = %7.3f Gamma = %7.3f"%tuple(r[3:6]))
+                        print(" get_symmetry: SpaceGroup = %s"%r[6])
                     else:
-                        print " get_symmetry: No symmetry defined."
+                        print(" get_symmetry: No symmetry defined.")
         finally:
             _self.unlock(r,_self)
         if _raising(r,_self): raise pymol.CmdException
@@ -237,7 +232,7 @@ PYMOL API
             r = _cmd.get_title(_self._COb,str(object),int(state)-1)
             if not quiet:
                 if r!=None:
-                    print " get_title: %s"%r      
+                    print(" get_title: %s"%r)      
         finally:
             _self.unlock(r,_self)
         if _raising(r,_self): raise pymol.CmdException
@@ -246,7 +241,8 @@ PYMOL API
 
     def angle(name=None, selection1="(pk1)", selection2="(pk2)", 
 	      selection3="(pk3)", mode=None, label=1, reset=0, 
-	      zoom=0, state=0, quiet=1, _self=cmd):
+	      zoom=0, state=0, quiet=1, _self=cmd,
+              state1=-3, state2=-3, state3=-3):
 
         '''
 DESCRIPTION
@@ -277,17 +273,17 @@ SEE ALSO
         if selection1=="(pk1)":
             if "pk1" not in _self.get_names('selections'):
                 if _feedback(fb_module.cmd,fb_mask.errors,_self):
-                    print "cmd-Error: The 'pk1' selection is undefined."
+                    print("cmd-Error: The 'pk1' selection is undefined.")
                 r = DEFAULT_ERROR
         if selection2=="(pk2)":
             if "pk2" not in _self.get_names('selections'):
                 if _feedback(fb_module.cmd,fb_mask.errors,_self):         
-                    print "cmd-Error: The 'pk2' selection is undefined."
+                    print("cmd-Error: The 'pk2' selection is undefined.")
                 r = DEFAULT_ERROR
         if selection3=="(pk3)":
             if "pk3" not in _self.get_names('selections'):
                 if _feedback(fb_module.cmd,fb_mask.errors,_self):         
-                    print "cmd-Error: The 'pk3' selection is undefined."
+                    print("cmd-Error: The 'pk3' selection is undefined.")
                 r = DEFAULT_ERROR
         if is_ok(r):
             r = DEFAULT_ERROR
@@ -323,7 +319,8 @@ SEE ALSO
                                str(selection2),
                                str(selection3),
                                int(mode),int(label),int(reset),
-                               int(zoom),int(quiet),int(state)-1)
+                               int(zoom),int(quiet),int(state)-1,
+                               int(state1)-1, int(state2)-1, int(state3)-1)
             finally:
                 _self.unlock(r,_self)
         if _raising(r,_self): raise pymol.CmdException
@@ -361,22 +358,22 @@ SEE ALSO
         if selection1=="(pk1)":
             if "pk1" not in _self.get_names('selections'):
                 if _feedback(fb_module.cmd,fb_mask.errors,_self):
-                    print "cmd-Error: The 'pk1' selection is undefined."
+                    print("cmd-Error: The 'pk1' selection is undefined.")
                 r = DEFAULT_ERROR
         if selection2=="(pk2)":
             if "pk2" not in _self.get_names('selections'):
                 if _feedback(fb_module.cmd,fb_mask.errors,_self):         
-                    print "cmd-Error: The 'pk2' selection is undefined."
+                    print("cmd-Error: The 'pk2' selection is undefined.")
                 r = DEFAULT_ERROR
         if selection3=="(pk3)":
             if "pk3" not in _self.get_names('selections'):
                 if _feedback(fb_module.cmd,fb_mask.errors,_self):         
-                    print "cmd-Error: The 'pk3' selection is undefined."
+                    print("cmd-Error: The 'pk3' selection is undefined.")
                 r = DEFAULT_ERROR
         if selection3=="(pk4)":
             if "pk4" not in _self.get_names('selections'):
                 if _feedback(fb_module.cmd,fb_mask.errors,_self):         
-                    print "cmd-Error: The 'pk4' selection is undefined."
+                    print("cmd-Error: The 'pk4' selection is undefined.")
                 r = DEFAULT_ERROR
         if is_ok(r):
             r = DEFAULT_ERROR
@@ -424,7 +421,8 @@ SEE ALSO
         
     def distance(name=None, selection1="(pk1)", selection2="(pk2)", 
 		 cutoff=None, mode=None, zoom=0, width=None, length=None,
-                 gap=None, label=1, quiet=1, reset=0, state=0, _self=cmd):
+                 gap=None, label=1, quiet=1, reset=0, state=0,
+                 state1=-3, state2=-3, _self=cmd):
 	
         '''
 DESCRIPTION
@@ -451,6 +449,17 @@ ARGUMENTS
 
     mode = 2: only show polar contact distances
 
+    mode = 3: like mode=0, but use distance_exclusion setting
+
+    mode = 4: distance between centroids (does not support
+              dynamic_measures; new in PyMOL 1.8.2)
+
+    state = int: object state to create the measurement object in
+    and to get coordinates from {default: 0 (all states)}
+
+    state1, state2 = int: overrule 'state' argument to measure distances
+    between different states {default: use state}
+
 EXAMPLES
 
     distance mydist, 14/CA, 29/CA
@@ -488,12 +497,12 @@ PYMOL API
         if selection1=="(pk1)":
             if "pk1" not in _self.get_names('selections'):
                 if _feedback(fb_module.cmd,fb_mask.errors,_self):
-                    print "cmd-Error: The 'pk1' selection is undefined."
+                    print("cmd-Error: The 'pk1' selection is undefined.")
                 r = DEFAULT_ERROR
         if selection2=="(pk2)":
             if "pk2" not in _self.get_names('selections'):
                 if _feedback(fb_module.cmd,fb_mask.errors,_self):         
-                    print "cmd-Error: The 'pk2' selection is undefined."
+                    print("cmd-Error: The 'pk2' selection is undefined.")
                 r = DEFAULT_ERROR
         if is_ok(r):
             r = DEFAULT_ERROR
@@ -527,7 +536,8 @@ PYMOL API
                 r = _cmd.dist(_self._COb,str(nam),"("+str(selection1)+")",
                               str(selection2),int(mode),float(cutoff),
                               int(label),int(quiet),int(reset),
-                              int(state)-1,int(zoom))
+                              int(state)-1,int(zoom),
+                              int(state1)-1, int(state2)-1)
                 if width!=None:
                     _self.set("dash_width",width,nam)
                 if length!=None:
@@ -543,8 +553,7 @@ PYMOL API
         return r
 
     # LEGACY support for cmd.dist
-    def dist(*arg,**kw):
-        return apply(distance,arg,kw)
+    dist = distance
 
     def get_povray(_self=cmd):
         '''
@@ -590,7 +599,7 @@ PYMOL API
         if not quiet:
             fov = _self.get_setting_float("field_of_view")
             dist = _self.get_view()[11]
-            print " 3Daac=%3.1f, 3Droll=0, 3Dc2c=0 0 1, 3Droo=%1.2f, 3Dcoo=0 0 %1.2f" % (fov, -dist, dist)
+            print(" 3Daac=%3.1f, 3Droll=0, 3Dc2c=0 0 1, 3Droo=%1.2f, 3Dcoo=0 0 %1.2f" % (fov, -dist, dist))
 
         return r
 
@@ -618,7 +627,7 @@ PYMOL API
         return r
     
     def get_version(quiet=1,_self=cmd):
-	'''
+        '''
 DESCRIPTION
  
     "get_version" returns a tuple of length six containing text,
@@ -630,7 +639,7 @@ PYMOL API
 
     cmd.get_version(int quiet)
 
-	'''
+        '''
         # get_version doesn't need the _COb and doesn't require a lock
         r = _cmd.get_version()
         if _raising(r,_self):
@@ -640,12 +649,12 @@ PYMOL API
             if quiet < 1 and _feedback(fb_module.cmd, fb_mask.results, _self):
                 import re
                 p = pymol.get_version_message(r)
-                print re.sub(r'^', ' ', p, re.M)
+                print(re.sub(r'^', ' ', p, re.M))
                 if quiet < 0:
                     if r[3]:
-                        print ' build date:', time.strftime('%c %Z', time.localtime(r[3]))
+                        print(' build date:', time.strftime('%c %Z', time.localtime(r[3])))
                     if r[4]:
-                        print ' git sha:', r[4]
+                        print(' git sha:', r[4])
         return r
 
     def get_vrml(version=2,_self=cmd): 
@@ -717,7 +726,7 @@ SEE ALSO
             _self.unlock(r,_self)
         if is_ok(r):
             if not quiet:
-                print " cmd.count_states: %d states."%r            
+                print(" cmd.count_states: %d states."%r)            
         if _raising(r,_self): raise pymol.CmdException
         return r
     
@@ -749,7 +758,7 @@ SEE ALSO
                 if r>0:
                     r = 0
             if r>=0 and not quiet:
-                print " cmd.get_movie_length: %d frames"%r      
+                print(" cmd.get_movie_length: %d frames"%r)      
         finally:
             _self.unlock(r,_self)
         if _raising(r,_self): raise pymol.CmdException
@@ -778,7 +787,7 @@ SEE ALSO
         try:
             _self.lock(_self)
             r = _cmd.count_frames(_self._COb)
-            if not quiet: print " cmd.count_frames: %d frames"%r      
+            if not quiet: print(" cmd.count_frames: %d frames"%r)      
         finally:
             _self.unlock(r,_self)
         if _raising(r,_self): raise pymol.CmdException
@@ -826,7 +835,7 @@ NOTES
             r = _cmd.overlap(_self._COb,str(selection1),str(selection2),
                                   int(state1)-1,int(state2)-1,
                                   float(adjust))
-            if not quiet: print " cmd.overlap: %5.3f Angstroms."%r
+            if not quiet: print(" cmd.overlap: %5.3f Angstroms."%r)
         finally:
             _self.unlock(r,_self)
         if _raising(r,_self): raise pymol.CmdException
@@ -861,7 +870,7 @@ NOTES
             r = _cmd.get_color(_self._COb,name,mode)
             if r==None:
                 if _feedback(fb_module.cmd,fb_mask.errors,_self):         
-                    print "cmd-Error: Unknown color '%s'."%name
+                    print("cmd-Error: Unknown color '%s'."%name)
         finally:
             _self.unlock(r,_self)
         if _raising(r,_self): raise pymol.CmdException
@@ -904,10 +913,10 @@ DESCRIPTION
         if _raising(r,_self): raise pymol.CmdException
 
         if not int(quiet):
-            print " OpenGL graphics engine:"
-            print "  GL_VENDOR:   ", r[0]
-            print "  GL_RENDERER: ", r[1]
-            print "  GL_VERSION:  ", r[2]
+            print(" OpenGL graphics engine:")
+            print("  GL_VENDOR:   ", r[0])
+            print("  GL_RENDERER: ", r[1])
+            print("  GL_VERSION:  ", r[2])
 
         return r
 
@@ -943,7 +952,7 @@ DESCRIPTION
             if _self._raising(_self=_self): raise pymol.CmdException
         elif not quiet:
             for a in r:
-                print " cmd.get_atom_coords: [%8.3f,%8.3f,%8.3f]"%(a)
+                print(" cmd.get_atom_coords: [%8.3f,%8.3f,%8.3f]"%(a))
         if _raising(r,_self): raise pymol.CmdException
         return r
 
@@ -1003,7 +1012,7 @@ DESCRIPTION
         if _raising(r,_self):
             raise pymol.CmdException
         elif not quiet:
-            print " cmd.get_position: [%8.3f,%8.3f,%8.3f]"%(r[0],r[1],r[2])
+            print(" cmd.get_position: [%8.3f,%8.3f,%8.3f]"%(r[0],r[1],r[2]))
         return r
 
     def get_distance(atom1="pk1",atom2="pk2",state=-1,quiet=1,_self=cmd):
@@ -1042,7 +1051,7 @@ PYMOL API
         if _raising(r,_self):
             raise pymol.CmdException
         elif not quiet:
-            print " cmd.get_distance: %5.3f Angstroms."%r
+            print(" cmd.get_distance: %5.3f Angstroms."%r)
         return r
 
     def get_angle(atom1="pk1",atom2="pk2",atom3="pk3",state=-1,quiet=1,_self=cmd):
@@ -1081,7 +1090,7 @@ PYMOL API
         if _raising(r,_self):
             raise pymol.CmdException
         elif not quiet:
-            print " cmd.get_angle: %5.3f degrees."%r
+            print(" cmd.get_angle: %5.3f degrees."%r)
         return r
         
     def get_dihedral(atom1="pk1",atom2="pk2",atom3="pk3",atom4="pk4",state=-1,quiet=1,_self=cmd):
@@ -1124,7 +1133,7 @@ PYMOL API
         if _raising(r,_self):
             raise pymol.CmdException
         elif not quiet:
-            print " cmd.get_dihedral: %5.3f degrees."%r
+            print(" cmd.get_dihedral: %5.3f degrees."%r)
         return r
 
     def get_model(selection="(all)",state=1,ref='',ref_state=0,_self=cmd):
@@ -1152,6 +1161,20 @@ PYMOL API
         if _raising(r,_self): raise pymol.CmdException
         return r
 
+    def get_bonds(selection="(all)", state=-1, _self=cmd):
+        '''
+DESCRIPTION
+
+    Get a list of (atm1, atm2, order) tuples.
+
+SEE ALSO
+
+    cmd.get_model().bond
+        '''
+        with _self.lockcm:
+            r = _cmd.get_bonds(_self._COb, selection, int(state))
+        return r
+
     def get_area(selection="(all)",state=1,load_b=0,quiet=1,_self=cmd):
         '''
 DESCRIPTION
@@ -1184,7 +1207,7 @@ SEE ALSO
         if r<0.0: # negative area signals error condition
             if _self._raising(): raise pymol.CmdException
         elif not quiet:
-            print " cmd.get_area: %5.3f Angstroms^2."%r
+            print(" cmd.get_area: %5.3f Angstroms^2."%r)
         return r
 
     def get_chains(selection="(all)",state=0,quiet=1,_self=cmd):
@@ -1217,7 +1240,7 @@ ARGUMENTS
         if _raising(r,_self):
             raise pymol.CmdException
         elif not quiet:
-            print " cmd.get_chains: ",str(r)
+            print(" cmd.get_chains: ",str(r))
         return r
 
 
@@ -1264,7 +1287,7 @@ SEE ALSO
         elif type=='group_objects':
             mode = 9
         else:
-            print "Error: unknown type: '%s'"%str(type)
+            print("Error: unknown type: '%s'"%str(type))
             if _raising(-1,_self): raise pymol.CmdException            
         try:
             _self.lock(_self)
@@ -1322,9 +1345,9 @@ SEE ALSO
             _self.unlock(r,_self)
         if is_error(r):
             if not quiet and _feedback(fb_module.cmd,fb_mask.errors,_self):      
-                print "Cmd-Error: unrecognized name."
+                print("Cmd-Error: unrecognized name.")
         elif not quiet:
-            print r
+            print(r)
         if _raising(r,_self): raise pymol.CmdException
         return r
 
@@ -1342,23 +1365,23 @@ PYMOL API
         '''
         r = DEFAULT_ERROR
         selection = str(selection)
-        l = apply(identify,(selection,mode,1))
+        l = identify(selection, mode)
         ll = len(l)
         if not ll:
             if _feedback(fb_module.cmd,fb_mask.errors,_self):
-                print "cmd-Error: atom %s not found by id_atom." % selection
+                print("cmd-Error: atom %s not found by id_atom." % selection)
             if _self._raising(_self=_self): raise pymol.CmdException
         elif ll>1:
             if _feedback(fb_module.cmd,fb_mask.errors,_self):
-                print "cmd-Error: multiple atoms %s found by id_atom." % selection
+                print("cmd-Error: multiple atoms %s found by id_atom." % selection)
             if _self._raising(_self=_self): raise pymol.CmdException
         else:
             r = l[0]
             if not quiet:
                 if mode:
-                    print " cmd.id_atom: (%s and id %d)"%(r[0],r[1])
+                    print(" cmd.id_atom: (%s and id %d)"%(r[0],r[1]))
                 else:
-                    print " cmd.id_atom: (id %d)"%r
+                    print(" cmd.id_atom: (id %d)"%r)
         if _raising(r,_self): raise pymol.CmdException
         return r
 
@@ -1393,10 +1416,10 @@ NOTES
                 if not quiet:
                     if mode:
                         for a in r:
-                            print " cmd.identify: (%s and id %d)"%(a[0],a[1])
+                            print(" cmd.identify: (%s and id %d)"%(a[0],a[1]))
                     else:
                         for a in r:
-                            print " cmd.identify: (id %d)"%a
+                            print(" cmd.identify: (id %d)"%a)
         if _raising(r,_self): raise pymol.CmdException
         return r
 
@@ -1431,7 +1454,7 @@ NOTE
             if is_list(r):
                 if len(r):
                     for a in r:
-                        print " cmd.index: (%s`%d)"%(a[0],a[1])
+                        print(" cmd.index: (%s`%d)"%(a[0],a[1]))
         if _raising(r,_self): raise pymol.CmdException
         return r
 
@@ -1505,8 +1528,8 @@ PYMOL API
         if not r:
             if _self._raising(_self=_self): raise pymol.CmdException
         elif not quiet:
-            print " cmd.extent: min: [%8.3f,%8.3f,%8.3f]"%(r[0][0],r[0][1],r[0][2])
-            print " cmd.extent: max: [%8.3f,%8.3f,%8.3f]"%(r[1][0],r[1][1],r[1][2])      
+            print(" cmd.extent: min: [%8.3f,%8.3f,%8.3f]"%(r[0][0],r[0][1],r[0][2]))
+            print(" cmd.extent: max: [%8.3f,%8.3f,%8.3f]"%(r[1][0],r[1][1],r[1][2]))      
         if _raising(r,_self): raise pymol.CmdException
         return r
 
@@ -1522,18 +1545,18 @@ USAGE
         
         r = cmd.get_phipsi(selection)
         if r!=None:
-            kees = r.keys()
+            kees = list(r.keys())
             kees.sort()
             if not quiet:
                 _self.feedback('push')
                 _self.feedback('disable','executive','actions')
                 for a in kees:
-                    _self.iterate("(%s`%d)"%a,"print ' %-9s "+
+                    _self.iterate("(%s`%d)"%a,"print(' %-9s "+
                                 ("( %6.1f, %6.1f )"%r[a])+
-                                "'%(resn+'-'+resi+':')")
+                                "'%(resn+'-'+resi+':'))")
                 _self.feedback('pop')
         elif _feedback(fb_module.cmd,fb_mask.errors,_self):      
-            print "cmd-Error: can't compute phi_psi"
+            print("cmd-Error: can't compute phi_psi")
         if _raising(r,_self): raise pymol.CmdException
         return r
 
@@ -1558,7 +1581,7 @@ USAGE
             _cmd.delete(_self._COb,"_count_tmp")
         finally:
             _self.unlock(r,_self)
-        if not quiet: print " count_atoms: %d atoms"%r
+        if not quiet: print(" count_atoms: %d atoms"%r)
         if _raising(r,_self): raise pymol.CmdException
         return r
 
@@ -1575,7 +1598,7 @@ USAGE
         with _self.lockcm:
             r = _cmd.count_discrete(_self._COb, str(selection))
             if not int(quiet):
-                print ' count_discrete: %d' % r
+                print(' count_discrete: %d' % r)
             return r
 
     def get_names_of_type(type,public=1,_self=cmd):
@@ -1596,8 +1619,8 @@ DESCRIPTION
     
         if obj:
             try:
-                types = map(_self.get_type,obj)
-                mix = map(None,obj,types)
+                types = list(map(_self.get_type,obj))
+                mix = list(zip(obj,types))
             except:
                 pass
         lst = []
@@ -1636,6 +1659,8 @@ DESCRIPTION
         states = _self.count_states('%' + name)
         if states < 2 and _self.get_setting_boolean('static_singletons'):
             return 1
+        if _self.get_setting_int('all_states', name):
+            return 0
         state = _self.get_setting_int('state', name)
         if state > states:
             raise pymol.CmdException('Invalid state %d for object %s' % (state, name))
@@ -1682,9 +1707,9 @@ SEE ALSO
         state, quiet = int(state), int(quiet)
 
         if state < 0:
-            states = [get_selection_state(selection)]
-        elif state == 0:
-            states = range(1, _self.count_states(selection)+1)
+            state = _self.get_selection_state(selection)
+        if state == 0:
+            states = list(range(1, _self.count_states(selection)+1))
         else:
             states = [state]
 
@@ -1703,7 +1728,7 @@ SEE ALSO
 
         com = cpv.scale(com, 1./totmass)
         if not quiet:
-            print ' Center of Mass: [%8.3f,%8.3f,%8.3f]' % tuple(com)
+            print(' Center of Mass: [%8.3f,%8.3f,%8.3f]' % tuple(com))
         return com
 
     def cif_get_array(name, key, dtype="s", quiet=1, _self=cmd):
@@ -1725,7 +1750,7 @@ ARGUMENTS
         if r and not int(quiet):
             n = len(r)
             r_print = r if n < 10 else (r[:9] + ['... (%d more items)' % (n - 9)])
-            print " %s:" % (key), ', '.join(map(str, r_print))
+            print(" %s:" % (key), ', '.join(map(str, r_print)))
         return r
 
     def get_assembly_ids(name, quiet=1, _self=cmd):
@@ -1737,5 +1762,5 @@ DESCRIPTION
         '''
         r = cif_get_array(name, "_pdbx_struct_assembly.id", _self=_self)
         if r and not int(quiet):
-            print " Assembly IDs:", ', '.join(r)
+            print(" Assembly IDs: %s" % ', '.join(r))
         return r
